<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.0">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About KeePassX</source>
        <translation>关于 KeePassX</translation>
    </message>
    <message>
        <source>KeePassX is distributed under the term of the GNU General Public License (GPL) version 2 or (at your option) version 3.</source>
        <translation>KeePassX 使用的是第 2 版 GNU 通用公共授权协议(GPL)(你可以根据需要选用第 3 版).</translation>
    </message>
    <message>
        <source>Revision</source>
        <translation>修改</translation>
    </message>
    <message>
        <source>Using:</source>
        <translation>使用:</translation>
    </message>
</context>
<context>
    <name>AutoType</name>
    <message>
        <source>Auto-Type - KeePassX</source>
        <translation>KeePassX - 自动输入</translation>
    </message>
    <message>
        <source>Couldn&apos;t find an entry that matches the window title:</source>
        <translation>无法找到符合窗口标题的项目</translation>
    </message>
</context>
<context>
    <name>AutoTypeAssociationsModel</name>
    <message>
        <source>Window</source>
        <translation>窗口</translation>
    </message>
    <message>
        <source>Sequence</source>
        <translation>顺序</translation>
    </message>
    <message>
        <source>Default sequence</source>
        <translation>默认顺序</translation>
    </message>
</context>
<context>
    <name>AutoTypeSelectDialog</name>
    <message>
        <source>Auto-Type - KeePassX</source>
        <translation>KeePassX - 自动输入</translation>
    </message>
    <message>
        <source>Select entry to Auto-Type:</source>
        <translation>选择自动输入的项目</translation>
    </message>
</context>
<context>
    <name>ChangeMasterKeyWidget</name>
    <message>
        <source>Password</source>
        <translation>密码</translation>
    </message>
    <message>
        <source>Enter password:</source>
        <translation>输入密码：</translation>
    </message>
    <message>
        <source>Repeat password:</source>
        <translation>重复密码：</translation>
    </message>
    <message>
        <source>Key file</source>
        <translation>秘钥文件</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>浏览</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>创建</translation>
    </message>
    <message>
        <source>Key files</source>
        <translation>秘钥文件</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>所有文件</translation>
    </message>
    <message>
        <source>Create Key File...</source>
        <translation>创建秘钥文件...</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <source>Unable to create Key File : </source>
        <translation>无法创建秘钥文件：</translation>
    </message>
    <message>
        <source>Select a key file</source>
        <translation>选择一个秘钥文件</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>问题</translation>
    </message>
    <message>
        <source>Do you really want to use an empty string as password?</source>
        <translation>你确定要使用空密码？</translation>
    </message>
    <message>
        <source>Different passwords supplied.</source>
        <translation>你输入了不同的密码</translation>
    </message>
    <message>
        <source>Failed to set key file</source>
        <translation>设置秘钥文件失败</translation>
    </message>
    <message>
        <source>Failed to set %1 as the Key file:
%2</source>
        <translation>无法设置 %1 为秘钥文件:
%2</translation>
    </message>
</context>
<context>
    <name>DatabaseOpenWidget</name>
    <message>
        <source>Enter master key</source>
        <translation>输入主密码</translation>
    </message>
    <message>
        <source>Key File:</source>
        <translation>秘钥文件：</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>密码：</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>浏览</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation>无法打开数据库</translation>
    </message>
    <message>
        <source>Can&apos;t open key file</source>
        <translation>无法打开秘钥文件</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>所有文件</translation>
    </message>
    <message>
        <source>Key files</source>
        <translation>秘钥文件</translation>
    </message>
    <message>
        <source>Select key file</source>
        <translation>选择秘钥文件</translation>
    </message>
</context>
<context>
    <name>DatabaseRepairWidget</name>
    <message>
        <source>Repair database</source>
        <translation>修复数据库</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <source>Can&apos;t open key file</source>
        <translation>无法打开密钥文件</translation>
    </message>
    <message>
        <source>Database opened fine. Nothing to do.</source>
        <translation>数据库打开正常。没什么可做的。</translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation>无法打开数据库</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>成功</translation>
    </message>
    <message>
        <source>The database has been successfully repaired
You can now save it.</source>
        <translation>数据库已经修复成功
现在可以保存数据库</translation>
    </message>
    <message>
        <source>Unable to repair the database.</source>
        <translation>无法修复数据库</translation>
    </message>
</context>
<context>
    <name>DatabaseSettingsWidget</name>
    <message>
        <source>Database name:</source>
        <translation>数据库名称：</translation>
    </message>
    <message>
        <source>Database description:</source>
        <translation>数据库介绍：</translation>
    </message>
    <message>
        <source>Transform rounds:</source>
        <translation>加密转换次数：</translation>
    </message>
    <message>
        <source>Default username:</source>
        <translation>默认用户名：</translation>
    </message>
    <message>
        <source>Use recycle bin:</source>
        <translation>使用垃圾桶：</translation>
    </message>
    <message>
        <source> MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <source>Benchmark</source>
        <translation>基准测试</translation>
    </message>
    <message>
        <source>Max. history items:</source>
        <translation>最大历史记录数：</translation>
    </message>
    <message>
        <source>Max. history size:</source>
        <translation>最大历史记录大小：</translation>
    </message>
</context>
<context>
    <name>DatabaseTabWidget</name>
    <message>
        <source>Root</source>
        <translation>根</translation>
    </message>
    <message>
        <source>KeePass 2 Database</source>
        <translation>KeePass 2 数据库</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>所有文件</translation>
    </message>
    <message>
        <source>Open database</source>
        <translation>打开数据库</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <source>File not found!</source>
        <translation>找不到文件！</translation>
    </message>
    <message>
        <source>Open KeePass 1 database</source>
        <translation>打开 KeePass 1 数据库</translation>
    </message>
    <message>
        <source>KeePass 1 database</source>
        <translation>KeePass 1 数据库</translation>
    </message>
    <message>
        <source>All files (*)</source>
        <translation>所有文件 (*)</translation>
    </message>
    <message>
        <source>Close?</source>
        <translation>关闭？</translation>
    </message>
    <message>
        <source>Save changes?</source>
        <translation>保存修改？</translation>
    </message>
    <message>
        <source>&quot;%1&quot; was modified.
Save changes?</source>
        <translation>&quot;%1&quot; 已被修改。
要保存吗？</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <source>Writing the database failed.</source>
        <translation>数据库写入失败</translation>
    </message>
    <message>
        <source>Save database as</source>
        <translation>另存数据库为</translation>
    </message>
    <message>
        <source>New database</source>
        <translation>新建数据库</translation>
    </message>
    <message>
        <source>locked</source>
        <translation>已锁</translation>
    </message>
    <message>
        <source>The database you are trying to open is locked by another instance of KeePassX.
Do you want to open it anyway? Alternatively the database is opened read-only.</source>
        <translation>你要打开的数据库已被另一个KeePassX锁住。
你确定要以只读方式的打开吗？</translation>
    </message>
    <message>
        <source>Lock database</source>
        <translation>锁住数据库</translation>
    </message>
    <message>
        <source>Can't lock the database as you are currently editing it.
Please press cancel to finish your changes or discard them.</source>
        <translation>不能锁住正在编辑的数据库。
选择取消继续编辑, 确定忽略编辑。</translation>
    </message>
    <message>
        <source>This database has never been saved.
You can save the database or stop locking it.</source>
        <translation>数据库未保存。
你可以保存数据库或者中止锁住它。</translation>
    </message>
    <message>
        <source>This database has been modified.
Do you want to save the database before locking it?
Otherwise your changes are lost.</source>
        <translation>数据库已经更改。
你想在锁住它以前保存修改吗？
否则修改将会丢失。</translation>
    </message>
    <message>
        <source>&quot;%1&quot; is in edit mode.
Discard changes and close anyway?</source>
        <translation>正在编辑 &quot;%1&quot; 。
仍然要放弃修改并且关闭吗？</translation>
    </message>
    <message>
        <source>Export database to CSV file</source>
        <translation>把数据库导出为CSV格式文件</translation>
    </message>
    <message>
        <source>CSV file</source>
        <translation>CSV格式文件</translation>
    </message>
    <message>
        <source>Writing the CSV file failed.</source>
        <translation>写入CSV格式文件失败</translation>
    </message>
    <message>
        <source>The database you are trying to save as is locked by another instance of KeePassX.
Do you want to save it anyway?</source>
        <translation>你要保存的数据库已被另一个KeePassX锁住。
你仍然要保存吗？</translation>
    </message>
</context>
<context>
    <name>DatabaseWidget</name>
    <message>
        <source>Change master key</source>
        <translation>更改主密码</translation>
    </message>
    <message>
        <source>Delete entry?</source>
        <translation>删除项目？</translation>
    </message>
    <message>
        <source>Do you really want to delete the entry &quot;%1&quot; for good?</source>
        <translation>你确定永远删除 &quot;%1&quot; 项目吗？</translation>
    </message>
    <message>
        <source>Delete entries?</source>
        <translation>删除项目？</translation>
    </message>
    <message>
        <source>Do you really want to delete %1 entries for good?</source>
        <translation>你确定永远删除 &quot;%1&quot; 项目吗？</translation>
    </message>
    <message>
        <source>Move entries to recycle bin?</source>
        <translation>移动项目到垃圾桶？</translation>
    </message>
    <message numerus="yes">
        <source>Do you really want to move %n entry(s) to the recycle bin?</source>
        <translation><numerusform>你确定要将 %n 个项目移到垃圾桶？</numerusform></translation>
    </message>
    <message>
        <source>Delete group?</source>
        <translation>删除群组？</translation>
    </message>
    <message>
        <source>Do you really want to delete the group &quot;%1&quot; for good?</source>
        <translation>你确定永远删除 &quot;%1&quot; 群组吗？</translation>
    </message>
    <message>
        <source>Current group</source>
        <translation>当前群组</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>无法计算主密码</translation>
    </message>
</context>
<context>
    <name>EditEntryWidget</name>
    <message>
        <source>Entry</source>
        <translation>项目</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>高级</translation>
    </message>
    <message>
        <source>Icon</source>
        <translation>图标</translation>
    </message>
    <message>
        <source>Auto-Type</source>
        <translation>自动输入</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>属性</translation>
    </message>
    <message>
        <source>History</source>
        <translation>历史记录</translation>
    </message>
    <message>
        <source>Entry history</source>
        <translation>项目历史</translation>
    </message>
    <message>
        <source>Add entry</source>
        <translation>添加项目</translation>
    </message>
    <message>
        <source>Edit entry</source>
        <translation>编辑项目</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <source>Different passwords supplied.</source>
        <translation>你输入了不同的密码</translation>
    </message>
    <message>
        <source>New attribute</source>
        <translation>新建属性</translation>
    </message>
    <message>
        <source>Select file</source>
        <translation>选择文件</translation>
    </message>
    <message>
        <source>Unable to open file</source>
        <translation>无法打开文件</translation>
    </message>
    <message>
        <source>Save attachment</source>
        <translation>保存附件</translation>
    </message>
    <message>
        <source>Unable to save the attachment:
</source>
        <translation>无法保存附件：
</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>明天</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation><numerusform>%n 周</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s)</source>
        <translation><numerusform>%n 个月</numerusform></translation>
    </message>
    <message>
        <source>1 year</source>
        <translation>1 年</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetAdvanced</name>
    <message>
        <source>Additional attributes</source>
        <translation>附加属性</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>添加</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>编辑</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>移除</translation>
    </message>
    <message>
        <source>Attachments</source>
        <translation>附件</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>打开</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetAutoType</name>
    <message>
        <source>Enable Auto-Type for this entry</source>
        <translation>打开此项目的自动输入</translation>
    </message>
    <message>
        <source>Inherit default Auto-Type sequence from the group</source>
        <translation>从父群组继承默认的自动输入顺序</translation>
    </message>
    <message>
        <source>Use custom Auto-Type sequence:</source>
        <translation>使用自定义自动输入顺序</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Window title:</source>
        <translation>窗口标题：</translation>
    </message>
    <message>
        <source>Use default sequence</source>
        <translation>使用默认顺序</translation>
    </message>
    <message>
        <source>Set custom sequence:</source>
        <translation>设置自定义顺序</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetHistory</name>
    <message>
        <source>Show</source>
        <translation>显示</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>还原</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>Delete all</source>
        <translation>全部删除</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetMain</name>
    <message>
        <source>Title:</source>
        <translation>标题：</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>用户名：</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>密码：</translation>
    </message>
    <message>
        <source>Repeat:</source>
        <translation>重复：</translation>
    </message>
    <message>
        <source>Gen.</source>
        <translation>生成.</translation>
    </message>
    <message>
        <source>URL:</source>
        <translation>网址：</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>过期</translation>
    </message>
    <message>
        <source>Presets</source>
        <translation>预设</translation>
    </message>
    <message>
        <source>Notes:</source>
        <translation>备注：</translation>
    </message>
</context>
<context>
    <name>EditGroupWidget</name>
    <message>
        <source>Group</source>
        <translation>群组</translation>
    </message>
    <message>
        <source>Icon</source>
        <translation>图标</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>属性</translation>
    </message>
    <message>
        <source>Add group</source>
        <translation>添加群组</translation>
    </message>
    <message>
        <source>Edit group</source>
        <translation>编辑群组</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>启用</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>禁用</translation>
    </message>
    <message>
        <source>Inherit from parent group (%1)</source>
        <translation>继承自父群组(%1)</translation>
    </message>
</context>
<context>
    <name>EditGroupWidgetMain</name>
    <message>
        <source>Name</source>
        <translation>名称</translation>
    </message>
    <message>
        <source>Notes</source>
        <translation>备注</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>过期</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
    <message>
        <source>Auto-type</source>
        <translation>自动输入</translation>
    </message>
    <message>
        <source>Use default auto-type sequence of parent group</source>
        <translation>使用父群组默认顺序</translation>
    </message>
    <message>
        <source>Set default auto-type sequence</source>
        <translation>设置默认自动输入顺序</translation>
    </message>
</context>
<context>
    <name>EditWidgetIcons</name>
    <message>
        <source>Use default icon</source>
        <translation>使用默认图标</translation>
    </message>
    <message>
        <source>Use custom icon</source>
        <translation>使用自定义图标</translation>
    </message>
    <message>
        <source>Add custom icon</source>
        <translation>添加自定义图标</translation>
    </message>
    <message>
        <source>Delete custom icon</source>
        <translation>删除自定义图标</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>图片</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>所有文件</translation>
    </message>
    <message>
        <source>Select Image</source>
        <translation>选择图片</translation>
    </message>
    <message>
        <source>Can&apos;t delete icon!</source>
        <translation>不能删除图标！</translation>
    </message>
    <message numerus="yes">
        <source>Can&apos;t delete icon. Still used by %n item(s).</source>
        <translation><numerusform>不能删除图标。仍在被 %n 个项目使用</numerusform></translation>
    </message>
</context>
<context>
    <name>EditWidgetProperties</name>
    <message>
        <source>Created:</source>
        <translation>已创建：</translation>
    </message>
    <message>
        <source>Modified:</source>
        <translation>已修改：</translation>
    </message>
    <message>
        <source>Accessed:</source>
        <translation>已存取：</translation>
    </message>
    <message>
        <source>Uuid:</source>
        <translation>Uuid(通用唯一识别码):</translation>
    </message>
</context>
<context>
    <name>EntryAttributesModel</name>
    <message>
        <source>Name</source>
        <translation>名称</translation>
    </message>
</context>
<context>
    <name>EntryHistoryModel</name>
    <message>
        <source>Last modified</source>
        <translation>最后修改</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>标题</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>用户名</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>网址</translation>
    </message>
</context>
<context>
    <name>EntryModel</name>
    <message>
        <source>Group</source>
        <translation>群组</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>标题</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>用户名</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>网址</translation>
    </message>
</context>
<context>
    <name>Group</name>
    <message>
        <source>Recycle Bin</source>
        <translation>垃圾桶</translation>
    </message>
</context>
<context>
    <name>KeePass1OpenWidget</name>
    <message>
        <source>Import KeePass1 database</source>
        <translation>导入 KeePass 1 数据库</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation>无法打开数据库。</translation>
    </message>
</context>
<context>
    <name>KeePass1Reader</name>
    <message>
        <source>Unable to read keyfile.</source>
        <translation>无法读取秘钥文件。</translation>
    </message>
    <message>
        <source>Not a KeePass database.</source>
        <translation>不是KeePass 数据库。</translation>
    </message>
    <message>
        <source>Unsupported encryption algorithm.</source>
        <translation>不支持的加密算法。</translation>
    </message>
    <message>
        <source>Unsupported KeePass database version.</source>
        <translation>不支持的KeePass 数据库版本。</translation>
    </message>
    <message>
        <source>Root</source>
        <translation>根</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>无法计算主密码</translation>
    </message>
</context>
<context>
    <name>KeePass2Reader</name>
    <message>
        <source>Not a KeePass database.</source>
        <translation>不是KeePass 的数据库。</translation>
    </message>
    <message>
        <source>Unsupported KeePass database version.</source>
        <translation>不支持的KeePass 数据库版本。</translation>
    </message>
    <message>
        <source>Wrong key or database file is corrupt.</source>
        <translation>秘钥错误或数据库损坏。</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>无法计算主密码</translation>
    </message>
    <message>
        <source>The selected file is an old KeePass 1 database (.kdb).

You can import it by clicking on Database &gt; 'Import KeePass 1 database'.
This is a one-way migration. You won&apos;t be able to open the imported database with the old KeePassX 0.4 version.</source>
        <translation>当前选择的文件是旧版本 KeePass 1 数据库（.kdb）。
你可以通过点击 数据库 &gt; &apos;导入KeePass 1 数据库’ 来导入。
这是不可逆的修改。导入后的数据库将无法由旧版的KeePassX 0.4版本打开。</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Fatal error while testing the cryptographic functions.</source>
        <translation>在测试加密函数时发生重大错误。</translation>
    </message>
    <message>
        <source>KeePassX - Error</source>
        <translation>KeePassX - 错误</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Database</source>
        <translation>数据库</translation>
    </message>
    <message>
        <source>Recent databases</source>
        <translation>最近的数据库</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>帮助</translation>
    </message>
    <message>
        <source>Entries</source>
        <translation>项目</translation>
    </message>
    <message>
        <source>Copy attribute to clipboard</source>
        <translation>将属性复制到剪贴板</translation>
    </message>
    <message>
        <source>Groups</source>
        <translation>群组</translation>
    </message>
    <message>
        <source>View</source>
        <translation>显示</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>退出</translation>
    </message>
    <message>
        <source>About</source>
        <translation>关于</translation>
    </message>
    <message>
        <source>Open database</source>
        <translation>打开数据库</translation>
    </message>
    <message>
        <source>Save database</source>
        <translation>保存数据库</translation>
    </message>
    <message>
        <source>Close database</source>
        <translation>关闭数据库</translation>
    </message>
    <message>
        <source>New database</source>
        <translation>新建数据库</translation>
    </message>
    <message>
        <source>Add new entry</source>
        <translation>新增项目</translation>
    </message>
    <message>
        <source>View/Edit entry</source>
        <translation>浏览/编辑项目</translation>
    </message>
    <message>
        <source>Delete entry</source>
        <translation>删除项目</translation>
    </message>
    <message>
        <source>Add new group</source>
        <translation>新增群组</translation>
    </message>
    <message>
        <source>Edit group</source>
        <translation>编辑群组</translation>
    </message>
    <message>
        <source>Delete group</source>
        <translation>删除群组</translation>
    </message>
    <message>
        <source>Save database as</source>
        <translation>另存数据库为</translation>
    </message>
    <message>
        <source>Change master key</source>
        <translation>更改主密码</translation>
    </message>
    <message>
        <source>Database settings</source>
        <translation>数据库设置</translation>
    </message>
    <message>
        <source>Import KeePass 1 database</source>
        <translation>导入KeePass 1 数据库</translation>
    </message>
    <message>
        <source>Clone entry</source>
        <translation>复制项目</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>查找</translation>
    </message>
    <message>
        <source>Copy username to clipboard</source>
        <translation>将用户名复制到剪贴板</translation>
    </message>
    <message>
        <source>Copy password to clipboard</source>
        <translation>将密码复制到剪贴板</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <source>Perform Auto-Type</source>
        <translation>执行自动输入</translation>
    </message>
    <message>
        <source>Open URL</source>
        <translation>打开网址</translation>
    </message>
    <message>
        <source>Lock databases</source>
        <translation>锁住数据库</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>标题</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>网址</translation>
    </message>
    <message>
        <source>Notes</source>
        <translation>备注</translation>
    </message>
    <message>
        <source>Show toolbar</source>
        <translation>显示工具栏</translation>
    </message>
    <message>
        <source>read-only</source>
        <translation>只读</translation>
    </message>
    <message>
        <source>Toggle window</source>
        <translation>切换窗口</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>工具</translation>
    </message>
    <message>
        <source>Copy username</source>
        <translation>复制用户名</translation>
    </message>
    <message>
        <source>Copy password</source>
        <translation>复制密码</translation>
    </message>
    <message>
        <source>Export to CSV file</source>
        <translation>导出为CSV格式文件</translation>
    </message>
    <message>
        <source>Repair database</source>
        <translation>修复数据库</translation>
    </message>
    <message>
        <source>KeePass 2 Database</source>
        <translation>KeePass 2 数据库</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>所有文件</translation>
    </message>
    <message>
        <source>Save repaired database</source>
        <translation>保存修复后的数据库</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <source>Writing the database failed.</source>
        <translation>数据库写入失败</translation>
    </message>
</context>
<context>
    <name>PasswordGeneratorWidget</name>
    <message>
        <source>Password:</source>
        <translation>密码：</translation>
    </message>
    <message>
        <source>Length:</source>
        <translation>长度：</translation>
    </message>
    <message>
        <source>Character Types</source>
        <translation>字符类型</translation>
    </message>
    <message>
        <source>Upper Case Letters</source>
        <translation>大写英文字母</translation>
    </message>
    <message>
        <source>Lower Case Letters</source>
        <translation>小写英文字母</translation>
    </message>
    <message>
        <source>Numbers</source>
        <translation>数字</translation>
    </message>
    <message>
        <source>Special Characters</source>
        <translation>特殊字符</translation>
    </message>
    <message>
        <source>Exclude look-alike characters</source>
        <translation>去除相似的字符</translation>
    </message>
    <message>
        <source>Ensure that the password contains characters from every group</source>
        <translation>确保密码包含每种的字符</translation>
    </message>
    <message>
        <source>Accept</source>
        <translation>接受</translation>
    </message>
</context>
<context>
    <name>QCommandLineParser</name>
    <message>
        <source>Displays version information.</source>
        <translation>显示版本信息</translation>
    </message>
    <message>
        <source>Displays this help.</source>
        <translation>显示帮助信息</translation>
    </message>
    <message>
        <source>Unknown option &apos;%1&apos;.</source>
        <translation>未知选项 &apos;%1&apos;。</translation>
    </message>
    <message>
        <source>Unknown options: %1.</source>
        <translation>未知选项： %1。</translation>
    </message>
    <message>
        <source>Missing value after &apos;%1&apos;.</source>
        <translation>在 &apos;%1&apos; 后缺少值。</translation>
    </message>
    <message>
        <source>Unexpected value after &apos;%1&apos;.</source>
        <translation>&apos;%1&apos; 后有无法识别的值。</translation>
    </message>
    <message>
        <source>[options]</source>
        <translation>[选项]</translation>
    </message>
    <message>
        <source>Usage: %1</source>
        <translation>已用：%1</translation>
    </message>
    <message>
        <source>Options:</source>
        <translation>选项：</translation>
    </message>
    <message>
        <source>Arguments:</source>
        <translation>参数：</translation>
    </message>
</context>
<context>
    <name>QSaveFile</name>
    <message>
        <source>Existing file %1 is not writable</source>
        <translation>当前文件%1 不可写</translation>
    </message>
    <message>
        <source>Writing canceled by application</source>
        <translation>应用程序取消写入</translation>
    </message>
    <message>
        <source>Partial write. Partition full?</source>
        <translation>写入不完整。磁盘满了吗？</translation>
    </message>
</context>
<context>
    <name>QtIOCompressor</name>
    <message>
        <source>Internal zlib error when compressing: </source>
        <translation>压缩函数库 zlib 出错：</translation>
    </message>
    <message>
        <source>Error writing to underlying device: </source>
        <translation>下层设备写入出错：</translation>
    </message>
    <message>
        <source>Error opening underlying device: </source>
        <translation>打开下层设备出错：</translation>
    </message>
    <message>
        <source>Error reading data from underlying device: </source>
        <translation>读取下层设备出错：</translation>
    </message>
    <message>
        <source>Internal zlib error when decompressing: </source>
        <translation>内部函数库 zlib 解压错误：</translation>
    </message>
</context>
<context>
    <name>QtIOCompressor::open</name>
    <message>
        <source>The gzip format not supported in this version of zlib.</source>
        <translation>当前版本的压缩函数库 zlib 不支援gzip。</translation>
    </message>
    <message>
        <source>Internal zlib error: </source>
        <translation>内部函数库 zlib 发生错误：</translation>
    </message>
</context>
<context>
    <name>SearchWidget</name>
    <message>
        <source>Find:</source>
        <translation>查找：</translation>
    </message>
    <message>
        <source>Case sensitive</source>
        <translation>区分大小写</translation>
    </message>
    <message>
        <source>Current group</source>
        <translation>当前群组</translation>
    </message>
    <message>
        <source>Root group</source>
        <translation>根群组</translation>
    </message>
</context>
<context>
    <name>SettingsWidget</name>
    <message>
        <source>Application Settings</source>
        <translation>应用程序设置</translation>
    </message>
    <message>
        <source>General</source>
        <translation>常规</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>安全</translation>
    </message>
</context>
<context>
    <name>SettingsWidgetGeneral</name>
    <message>
        <source>Remember last databases</source>
        <translation>记住最近的数据库</translation>
    </message>
    <message>
        <source>Open previous databases on startup</source>
        <translation>在启动时打开最近的数据库</translation>
    </message>
    <message>
        <source>Automatically save on exit</source>
        <translation>离开后自动保存</translation>
    </message>
    <message>
        <source>Automatically save after every change</source>
        <translation>修改后自动保存</translation>
    </message>
    <message>
        <source>Minimize when copying to clipboard</source>
        <translation>复制到剪贴板后最小化</translation>
    </message>
    <message>
        <source>Use group icon on entry creation</source>
        <translation>新增项目时使用群组图标</translation>
    </message>
    <message>
        <source>Global Auto-Type shortcut</source>
        <translation>自动输入全局快捷键</translation>
    </message>
    <message>
        <source>Use entry title to match windows for global auto-type</source>
        <translation>使用项目标题来查找自动输入的目标窗口</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>语言</translation>
    </message>
    <message>
        <source>Show a system tray icon</source>
        <translation>显示任务栏图标</translation>
    </message>
    <message>
        <source>Hide window to system tray when minimized</source>
        <translation>将窗口最小化至任务栏</translation>
    </message>
    <message>
        <source>Remember last key files</source>
        <translation>记住最近的秘钥文件</translation>
    </message>
</context>
<context>
    <name>SettingsWidgetSecurity</name>
    <message>
        <source>Clear clipboard after</source>
        <translation>在多久后清除剪贴板</translation>
    </message>
    <message>
        <source> sec</source>
        <translation>秒</translation>
    </message>
    <message>
        <source>Lock databases after inactivity of</source>
        <translation>在多久没有动作之后锁住数据库</translation>
    </message>
    <message>
        <source>Show passwords in cleartext by default</source>
        <translation>默认以明码显示密码</translation>
    </message>
    <message>
        <source>Always ask before performing auto-type</source>
        <translation>在执行自动输入前询问</translation>
    </message>
</context>
<context>
    <name>UnlockDatabaseWidget</name>
    <message>
        <source>Unlock database</source>
        <translation>解锁数据库</translation>
    </message>
</context>
<context>
    <name>WelcomeWidget</name>
    <message>
        <source>Welcome!</source>
        <translation>欢迎！</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>KeePassX - cross-platform password manager</source>
        <translation>KeePassX - 跨平台密码管理软件</translation>
    </message>
    <message>
        <source>filename of the password database to open (*.kdbx)</source>
        <translation>打开密码数据库文件名(*.kdbx)</translation>
    </message>
    <message>
        <source>path to a custom config file</source>
        <translation>自定义配置文件路径</translation>
    </message>
    <message>
        <source>key file of the database</source>
        <translation>数据库秘钥文件</translation>
    </message>
</context>
</TS>